# Check if .vl key exists
try {
    $regKey = Get-Item -Path "Registry::HKEY_CLASSES_ROOT\.vl" -ErrorAction Stop
} catch {
    Write-Host "Registry key for '.vl' not found, aborting."
    Exit
}

# Set FriendlyTypeName
Set-ItemProperty -Path "Registry::HKEY_CLASSES_ROOT\.vl" -Name "FriendlyTypeName" -Value "VL Document"

# Create ShellNew key and set FileName
$shellNewPath = "Registry::HKEY_CLASSES_ROOT\.vl\ShellNew"
$documentFolderPath = [Environment]::GetFolderPath("MyDocuments")
$vlFilePath = Join-Path $documentFolderPath "vvvv\EmptyDocument.vl"

try {
    $shellNewKey = Get-Item -Path $shellNewPath -ErrorAction Stop
} catch {
    $shellNewKey = New-Item -Path $shellNewPath -Force
}

Set-ItemProperty -Path $shellNewKey.PSPath -Name "FileName" -Value $vlFilePath

# Check for the presence of EmptyDocument.vl and create if not exists
if (-not (Test-Path $vlFilePath)) {
    $vlFileContent = @"
<?xml version="1.0" encoding="utf-8"?>
<Document xmlns:p="property" xmlns:r="reflection" Id="TEoViClnIiPLPD6d5SyQmz" LanguageVersion="2023.5.3-0334-gdf8d29056f" Version="0.128">
  <NugetDependency Id="R3sWC8Aqk6BOEAE2UjKeGh" Location="VL.CoreLib" Version="2023.5.3-0334-gdf8d29056f" />
  <Patch Id="EeTlA4Q3fthPdUynd1PrC4">
    <Canvas Id="JDCTBaxsmzqOxqFLyMxKgM" DefaultCategory="Main" BordersChecked="false" CanvasType="FullCategory" />
    <!--

    ************************ Application ************************

-->
    <Node Name="Application" Bounds="100,100" Id="LxIcqvjMj24Oqnn28HWSGa">
      <p:NodeReference>
        <Choice Kind="ContainerDefinition" Name="Process" />
        <CategoryReference Kind="Category" Name="Primitive" />
      </p:NodeReference>
      <Patch Id="MbRsIfAhLUzQIdJQtLozQg">
        <Canvas Id="IGnkmNJWACSPew5GdbEtiZ" CanvasType="Group" />
        <Patch Id="HEESEEOhZ8HNAmx3nOCyNZ" Name="Create" />
        <Patch Id="UtfCQhaKmSqPTSfm3HufVk" Name="Update" />
        <!--

    ************************  ************************

-->
        <ProcessDefinition Id="LQKAGzmipdpMgOMHsPP99t">
          <Fragment Id="QzMYA9kUvfEOmH4aKTH12c" Patch="HEESEEOhZ8HNAmx3nOCyNZ" Enabled="true" />
          <Fragment Id="LWxR5p9Jd4aPJI8iywJaHn" Patch="UtfCQhaKmSqPTSfm3HufVk" Enabled="true" />
        </ProcessDefinition>
      </Patch>
    </Node>
  </Patch>
</Document>
"@

    $vlFileDirectory = Split-Path $vlFilePath -Parent
    if (-not (Test-Path $vlFileDirectory)) {
        New-Item -Path $vlFileDirectory -ItemType Directory -Force
    }

    $vlFileContent | Out-File -FilePath $vlFilePath -Encoding UTF8
}

Write-Host "Operation completed successfully."
